/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 */

package ru.ulstu.extractor.service;

import org.springframework.stereotype.Service;
import ru.ulstu.extractor.model.Branch;
import ru.ulstu.extractor.model.Commit;
import ru.ulstu.extractor.model.Repository;
import ru.ulstu.extractor.repository.BranchRepository;

import javax.transaction.Transactional;
import java.util.List;

@Service
public class BranchService {
    private final BranchRepository branchRepository;
    private final CommitService commitService;

    public BranchService(BranchRepository branchRepository,
                         CommitService commitService) {
        this.branchRepository = branchRepository;
        this.commitService = commitService;
    }

    @Transactional
    public Branch save(Branch branch, List<Commit> commits) {
        List<Commit> commitsToRemove = branch.getCommits();
        branch.getCommits().clear();
        commitService.delete(commitsToRemove);
        branch.setCommits(commitService.save(commits));
        return branchRepository.save(branch);
    }

    public Branch findByRepositoryAndName(Repository repository, String branchName) {
        return branchRepository.findByRepositoryAndName(repository, branchName);
    }
}
